@@ -319,17 +319,19 @@ class MLSchema(Schema):
     def populate_registry():
         """ Loads all the base schemas for the schema registry. """
 
+        rootLogger = logging.getLogger('mlspeclib')
+
         schemas_to_process = []
         no_base = []
         has_base = []
         last = []
 
         load_root = os.path.dirname(mlspeclib.__file__)
-        # logging.debug(f"Registry load root: {load_root}")
+        rootLogger.debug(f"Registry load root: {load_root}")
         load_path = Path(load_root).glob("schemas/**/*.yaml")
-        # logging.debug(f"Registry load path: {load_path}")
+        rootLogger.debug(f"Registry load path: {load_path}")
         load_list = list(load_path)
-        # logging.debug(f"Registry load list: {load_list}")
+        rootLogger.debug(f"Registry load list: {load_list}")
 
         for schema_file in load_list:
             schema_text = schema_file.read_text('utf-8')
@@ -405,11 +407,13 @@ class MLSchema(Schema):
         all_schemas = no_base_schemas + schemas_with_base + last_schemas
 
         if len(files_with_errors) > 0:
+            rootLogger = logging.getLogger('mlspeclib')
             error_string = ""
             for err in files_with_errors:
-                error_string += f"{err[0]}: {err[1]}\n"
+                error_string += f"::CRITICAL - {err[0]}: {err[1]}\n"
 
-            print(error_string)
+            # TODO: Move to root logger
+            rootLogger.critical(error_string)
             return False
 
         for schema_dict in all_schemas:
